ubii.framework.services module
==============================

.. automodule:: ubii.framework.services
    :members:
    :exclude-members: ServiceCall

.. autoclass:: ubii.framework.services.ServiceCall
    :members:
    :special-members: __call__
